@@ -1,12 +1,13 @@
 # -*- coding: utf-8 -*-
 # @Time    : 2021-07-30 20:14
 # @Author  : zbmain
-__version__ = '0.0.23'
+__version__ = '0.0.25'
 __author__ = 'winwin'
 
 from . import env
+from . import managers
 from . import utils
 from .utils import support
 from .utils.func_util import *
 
-__all__ = ['env', 'support', 'view_df', 'warning_ignored', 'set_seed', 'delay']
+__all__ = ['env', 'support', 'managers', 'view_df', 'warning_ignored', 'set_seed', 'delay']
