@@ -2,6 +2,7 @@
 # @Time    : 2022-07-20 20:23
 # @Author  : zbmain
 
+from ..utils import file_util
 from ..utils import func_util
 from ..utils import list_util
 from ..utils import os_util
@@ -9,4 +10,4 @@ from ..utils import pool_util
 from ..utils import str_util
 from ..utils import support
 
-__all__ = ['support', 'func_util', 'os_util', 'str_util', 'pool_util', 'list_util']
+__all__ = ['support', 'func_util', 'os_util', 'str_util', 'pool_util', 'list_util', 'file_util']
