@@ -6,8 +6,6 @@ __all__ = ['view_df', 'warning_ignored', 'set_seed', 'delay']
 
 import time
 
-import pandas
-
 
 def delay(second: int):
     time.sleep(second)
@@ -22,7 +20,7 @@ def delay(second: int):
     return wrapper
 
 
-def view_df(df: pandas.DataFrame, head_num: int = 5, tail_num: int = 5, comment: str = 'DataFrame'):
+def view_df(df, head_num: int = 5, tail_num: int = 5, comment: str = 'DataFrame'):
     print('%s row_size:%d' % (comment, df.shape[0]))
     return None if -1 in (head_num, tail_num) else df.head(head_num).append(df.tail(tail_num))
 
@@ -38,6 +36,7 @@ def pandas_set(max_row: int = 0, max_col: int = 0, max_col_w: int = 0, max_char_
     @param float_precision: 显示浮点数最多位数
     @return: None
     """
+    import pandas
     max_row and pandas.set_option('display.max_rows', max_row)
     max_col and pandas.set_option('display.max_columns', max_col)
     max_col_w and pandas.set_option('display.max_colwidth', max_col_w)
